@@ -2,7 +2,7 @@ package Dist::Zilla::PluginBundle::Author::DOHERTY;
 # ABSTRACT: configure Dist::Zilla like DOHERTY
 use strict;
 use warnings;
-our $VERSION = '0.021'; # VERSION
+our $VERSION = 'v0.22'; # VERSION
 
 
 # Dependencies
@@ -20,7 +20,7 @@ use Dist::Zilla::Plugin::Git::Check                     qw();
 use Dist::Zilla::Plugin::Git::Commit                    qw();
 use Dist::Zilla::Plugin::GitHub                    0.13 qw(); # Support for pointing to parent forks
 use Dist::Zilla::Plugin::Git::NextVersion               qw();
-use Dist::Zilla::Plugin::Git::Tag                       qw();
+use Dist::Zilla::Plugin::Git::Tag              1.112380 qw(); # Support for signed tags
 use Dist::Zilla::Plugin::InstallGuide                   qw();
 use Dist::Zilla::Plugin::InstallRelease           0.006 qw(); # to detect failed installs
 use Dist::Zilla::Plugin::MinimumPerl              1.003 qw(); # to ignore non-perl files
@@ -45,10 +45,11 @@ sub configure {
         my $defaults = {
             changelog       => 'Changes',
             twitter         => 1,
-            version_regexp  => '^(?:v|release-)(.+)$',
-            tag_format      => 'v%v',
+            version_regexp  => '^(v?.+)$',
+            tag_format      => '%v%t',
             fake_release    => 0,
             surgical        => 0,
+            push_to         => 'origin',
         };
         my $config = $self->config_slice(
             'version_regexp',
@@ -58,6 +59,7 @@ sub configure {
             'twitter',
             'surgical',
             'critic_config',
+            'push_to',
             { enable_tests  => 'enable'  },
             { disable_tests => 'disable' },
         );
@@ -123,22 +125,26 @@ sub configure {
             allow_dirty => [$conf->{changelog}, @dzil_files_for_scm],
             commit_msg => 'Released %v%t',
         } ],
-        [ 'Git::Tag' => { tag_format => $conf->{tag_format} } ],
-        'Git::Push',
-        [ 'GitHub::Update' => { cpan => 0, p3rl => 1 } ],
+        [ 'Git::Tag' => {
+            tag_format  => $conf->{tag_format},
+            tag_message => "Released $conf->{tag_format}",
+            signed      => 1,
+        } ],
+        [ 'Git::Push' => { push_to => $conf->{push_to} } ],
+        [ 'GitHub::Update' => { metacpan => 1 } ],
     );
     $self->add_plugins([ 'Twitter' => {
             hash_tags => '#perl #cpan',
             url_shortener => 'Googl',
-            tweet_url => 'https://metacpan.org/release/{{$DIST}}',
+            tweet_url => 'https://metacpan.org/release/{{$AUTHOR_UC}}/{{$DIST}}-{{$VERSION}}/',
         } ]) if ($conf->{twitter} and not $conf->{fake_release});
 
     $self->add_bundle(
         'TestingMania' => {
-            enable      => $conf->{enable},
-            disable     => $conf->{disable},
-            changelog   => $conf->{changelog},
-            critic_config => $conf->{critic_config},
+            enable          => $conf->{enable},
+            disable         => $conf->{disable},
+            changelog       => $conf->{changelog},
+            critic_config   => $conf->{critic_config},
         }
      );
 
@@ -165,7 +171,7 @@ Dist::Zilla::PluginBundle::Author::DOHERTY - configure Dist::Zilla like DOHERTY
 
 =head1 VERSION
 
-version 0.021
+version v0.22
 
 =head1 SYNOPSIS
 
@@ -210,15 +216,15 @@ Default is none.
 C<tag_format> specifies how a git release tag should be named. This is
 passed to C<< L<Git::Tag|Dist::Zilla::Plugin::Git::Tag> >>.
 
-Default is C< 'v%v' >.
+Default is C< %v%t >.
 
 =item *
 
-C<version_regex> specifies a regexp to find the version number part of
+C<version_regexp> specifies a regexp to find the version number part of
 a git release tag. This is passed to
 C<< L<Git::NextVersion|Dist::Zilla::Plugin::Git::NextVersion> >>.
 
-Default is C<< '^(?:v|release-)(.+)$' >>.
+Default is C<< ^(v.+)$ >>.
 
 =item *
 
@@ -238,6 +244,12 @@ C<changelog> is the filename of the changelog.
 
 Default is F<Changes>.
 
+=item *
+
+C<push_to> is the git remote to push to; can be specified multiple times.
+
+Default is C<origin>.
+
 =back
 
 =head1 SEE ALSO
